@@ -172,14 +172,7 @@ class AkinonCloudClient:
             raise AkinonCLIError("Project App could not found.")
         return response
 
-    def get_project_app_logs(self, project_id, project_app_id, start_datetime, end_datetime, process_type):
-        data = {
-            "start_datetime": start_datetime.isoformat(),
-            "end_datetime": end_datetime.isoformat(),
-            "page": 1,
-            "page_size": 10000,
-            "applications": process_type
-        }
+    def get_project_app_logs(self, project_id, project_app_id, data):
         return self._send_request("POST", "project_apps_logs",
                                   params={"project_id": project_id, "project_app_id": project_app_id},
                                   data=data)
