@@ -429,38 +429,41 @@ class ProjectApps(Controller):
         arguments=[
             (['project_id'], {'help': 'Project ID', 'action': 'store', }),
             (['project_app_id'], {'help': 'Project App ID', 'action': 'store'}),
-            (['-o', '--offset'], {'help': 'Offset (second)', 'action': 'store', 'dest': "offset", 'default': 10}),
-            (['-l', '--limit'], {'help': 'Limit (second)', 'action': 'store', 'dest': "limit", 'default': 5}),
             (['-p', '--process'], {'help': 'Process type', 'action': 'store', 'dest': "process_type", 'default': ''}),
         ],
     )
     def logs(self):
-        offset = int(self.app.pargs.offset)
-        limit = int(self.app.pargs.limit)
         process_type = self.app.pargs.process_type or []
         if process_type:
             process_type = [process_type]
-        query_end_datetime = datetime.now(timezone.utc) - timedelta(seconds=offset)
-        query_start_datetime = query_end_datetime - timedelta(seconds=limit)
+
         project_id = self.app.pargs.project_id
         project_app_id = self.app.pargs.project_app_id
+        data = {"applications": process_type}
+
         response = self.app.client.get_project_app_logs(
             project_id=project_id,
             project_app_id=project_app_id,
-            start_datetime=query_start_datetime,
-            end_datetime=query_end_datetime,
-            process_type=process_type
+            data=data,
         )
         rows = response.data.get('items', [])
         for row in rows:
             if 'message' not in row:
                 row['message'] = ""
-        self.app.render(
-            renderer_type="realtime_log",
-            data=response.data,
-            rows=rows,
-            is_succeed=response.is_succeed
-        )
+
+        if len(rows) > 0:
+            self.app.render(
+                renderer_type="realtime_log",
+                data=response.data,
+                rows=rows,
+                is_succeed=response.is_succeed,
+            )
+        else:
+            self.app.render(
+                data={},
+                renderer_type="text",
+                custom_text="No logs found in 1 minute",
+            )
 
     @ex(
         help='Export Project App Logs',
